@@ -16,7 +16,7 @@ import gi
 
 from gi.repository import Gtk as gtk
 from gi.repository import Gdk as gdk
-from gi.repository import GObject
+from gi.repository import GLib
 from gi.repository import Pango
 
 import re
@@ -365,7 +365,7 @@ class ConsoleView(gtk.TextView):
     self.connect('key-press-event', self.onKeyPress)
     
   def write(self, text, editable=False):
-    GObject.idle_add(self._write, text, editable)
+    GLib.idle_add(self._write, text, editable)
 
   def _write(self, text, editable=False):
     '''
@@ -399,7 +399,7 @@ class ConsoleView(gtk.TextView):
 
 
   def showPrompt(self, prompt):
-    GObject.idle_add(self._showPrompt, prompt)
+    GLib.idle_add(self._showPrompt, prompt)
 
   def _showPrompt(self, prompt):
     '''
@@ -413,7 +413,7 @@ class ConsoleView(gtk.TextView):
                                self.text_buffer.get_end_iter())
 
   def changeLine(self, text):
-    GObject.idle_add(self._changeLine, text)
+    GLib.idle_add(self._changeLine, text)
 
   def _changeLine(self, text):
     '''
@@ -440,7 +440,7 @@ class ConsoleView(gtk.TextView):
     return rv
 
   def showReturned(self, text):
-    GObject.idle_add(self._showReturned, text)
+    GLib.idle_add(self._showReturned, text)
 
   def _showReturned(self, text):
     '''
